@@ -1,6 +1,7 @@
 from starlette.requests import Request
 from starlette.websockets import WebSocket
 import inspect
+import traceback
 
 
 class Middleware:
@@ -8,12 +9,17 @@ class Middleware:
         self.app = app
 
     async def __call__(self, scope, receive, send):
-        request = Request(scope=scope, receive=receive)
-        websocket = WebSocket(scope=scope, receive=receive, send=send)
+        try:
+            request = Request(scope=scope, receive=receive)
+            websocket = WebSocket(scope=scope, receive=receive, send=send)
 
-        response = await self.app.handle_request(request, websocket)
+            response = await self.app.handle_request(request, websocket)
 
-        await response(scope, receive, send)
+            await response(scope, receive, send)
+        except:
+            error = traceback.format_exc()
+            print(error)
+            response = self.exception_handler.handle_error(request, error)
 
     def add(self, middleware_cls, *args):
         if args == []:
